Data
====

.. currentmodule:: pqp.data

.. autoclass:: Data
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Data.n

   .. rubric:: Methods Summary

   .. autosummary::

      ~Data.domain_of
      ~Data.quantize

   .. rubric:: Attributes Documentation

   .. autoattribute:: n

   .. rubric:: Methods Documentation

   .. automethod:: domain_of
   .. automethod:: quantize
